@@ -29,7 +29,7 @@
 
 #include <config.h>
 #include <glib/gi18n-lib.h>
-#include "libgnomeui/gnome-rr-labeler.h"
+#include "gnome-rr-labeler.h"
 #include <gtk/gtk.h>
 
 #include <X11/Xproto.h>
@@ -411,11 +411,16 @@ gnome_rr_labeler_hide (GnomeRRLabeler *labeler)
 
 	g_return_if_fail (GNOME_IS_RR_LABELER (labeler));
 
+	if (labeler->windows == NULL)
+		return;
+
 	for (i = 0; i < labeler->num_outputs; i++)
 		if (labeler->windows[i] != NULL) {
 			gtk_widget_destroy (labeler->windows[i]);
 			labeler->windows[i] = NULL;
 		}
+	g_free (labeler->windows);
+	labeler->windows = NULL;
 }
 
 void
